NoGC

Struct NoGC 

pub struct NoGC(());
Token that ensures that no GC can happen while it is alive.

This type is similar to &JSContext, but it is used in cases where no actual context is needed.

For more info and examples see JSContext.

This type can be obtained from JSContext (and will be bounded to it) or constructed from thin air (unsafe).

fn f() {
    // safe construction is not possible
    mozjs::context::NoGC(());
}

Tuple Fields

0: ()

Implementations

Source

impl NoGC

pub unsafe fn new() -> Self

Creates new NoGC token from thin air.

This is more safe than constructing JSContext from thin air as the promise here (of no GC) is weaker, but one should still prefer passing NoGC down as an argument.

Safety

One must ensure that no JSContext or existing NoGC is alive while this NoGC is alive.